## 🎉 0.7.0 (25-09-2025)

### ✨ Nuevas características
- Corrección del empaquetado para generar traer los templates

### 🐛 Correcciones
- Corregido error de alineación en paginación del footer.
- Mejorada compatibilidad con Django 4.2+.

### 📚 Documentación
- Actualizado README con badges y uso de componentes.

### 🧹 Mejoras internas
- Refactorizado builder para mayor escalabilidad.
- Optimizado manejo de estilos CSS.
- Generacion de componentes vacios para la generacion de pdfs oficiales

---

## 🚀 Próxima versión

*(Cambios que están en desarrollo y aún no se han publicado)*

### ✨ Nuevas características
- ...

### 🐛 Correcciones
- ...

### 🧹 Mejoras internas
- ...